#include "aruco_markers/utils.hpp"
#include <opencv2/core.hpp>

namespace aruco_markers
{
namespace utils
{
bool isVec3dZero(const cv::Vec3d & vec)
{
  return vec[0] == 0.0 && vec[1] == 0.0 && vec[2] == 0.0;
}

cv::aruco::PREDEFINED_DICTIONARY_NAME dictNameToEnum(const std::string & dict_name)
{
  std::unordered_map<std::string, cv::aruco::PREDEFINED_DICTIONARY_NAME> dict_name_map = {
    {"DICT_4X4_50", cv::aruco::DICT_4X4_50},
    {"DICT_4X4_100", cv::aruco::DICT_4X4_100},
    {"DICT_4X4_250", cv::aruco::DICT_4X4_250},
    {"DICT_4X4_1000", cv::aruco::DICT_4X4_1000},
    {"DICT_5X5_50", cv::aruco::DICT_5X5_50},
    {"DICT_5X5_100", cv::aruco::DICT_5X5_100},
    {"DICT_5X5_250", cv::aruco::DICT_5X5_250},
    {"DICT_5X5_1000", cv::aruco::DICT_5X5_1000},
    {"DICT_6X6_50", cv::aruco::DICT_6X6_50},
    {"DICT_6X6_100", cv::aruco::DICT_6X6_100},
    {"DICT_6X6_250", cv::aruco::DICT_6X6_250},
    {"DICT_6X6_1000", cv::aruco::DICT_6X6_1000},
    {"DICT_7X7_50", cv::aruco::DICT_7X7_50},
    {"DICT_7X7_100", cv::aruco::DICT_7X7_100},
    {"DICT_7X7_250", cv::aruco::DICT_7X7_250},
    {"DICT_7X7_1000", cv::aruco::DICT_7X7_1000},
    {"DICT_ARUCO_ORIGINAL", cv::aruco::DICT_ARUCO_ORIGINAL},
    {"DICT_APRILTAG_16h5", cv::aruco::DICT_APRILTAG_16h5},
    {"DICT_APRILTAG_25h9", cv::aruco::DICT_APRILTAG_25h9},
    {"DICT_APRILTAG_36h10", cv::aruco::DICT_APRILTAG_36h10},
    {"DICT_APRILTAG_36h11", cv::aruco::DICT_APRILTAG_36h11},
  };
  if (dict_name_map.find(dict_name) != dict_name_map.end()) {
    return dict_name_map[dict_name];
  } else {
    throw std::invalid_argument("Invalid dictionary");
  }
}
}   // namespace utils
} // namespace aruco_markers
